package com.diagbot.repository;

import com.diagbot.entity.node.EntityInfo;
import com.diagbot.entity.node.Group;
import org.springframework.data.neo4j.annotation.Query;
import org.springframework.data.neo4j.repository.Neo4jRepository;
import org.springframework.data.repository.query.Param;

import java.util.List;


public interface GroupRepository extends Neo4jRepository<Group, Long> {

    List<Group> findByNameContaining(String name);

    List<Group> findByNameIs(String name);

    List<Group> findByNameIn(List<String> names);

    @Query("merge (n:禁忌人群{name:{name}})  " +
            "on create set  " +
            "n.拼音编码={pycode}," +
            "n.静态知识标识={is_kl}," +
            "n.状态={status}," +
            "n.最大值={maxValue}," +
            "n.最小值={minValue}," +
            "n.范围={range}," +
            "n.单位={unit}, " +
            "n.禁忌人群指标={indication} " +
            "on match set  " +
            "n.拼音编码={pycode}," +
            "n.静态知识标识={is_kl}," +
            "n.状态={status}," +
            "n.最大值={maxValue}," +
            "n.最小值={minValue}," +
            "n.范围={range}," +
            "n.单位={unit}, " +
            "n.禁忌人群指标={indication} " +
            "RETURN n,[ (n)-[r]->(m) | [ r, m ] ], ID(n)\n")
    Group createOrUpdate(@Param("name") String name,
                         @Param("is_kl") Integer is_kl,
                         @Param("pycode") String pycode,
                         @Param("status") Integer status,
                         @Param("maxValue") Double maxValue,
                         @Param("minValue") Double minValue,
                         @Param("range") Integer range,
                         @Param("unit") String unit,
                         @Param("indication") String indication);

    @Query("create (n:禁忌人群) \n" +
            "set  " +
            "n.name = :#{#entityInfo.name}," +
            "n.拼音编码 = :#{#entityInfo.pycode}," +
            "n.静态知识标识 = :#{#entityInfo.is_kl}," +
            "n.状态 = :#{#entityInfo.status}" +
            "\n" +
            "RETURN n,[ (n)-[r]->(m) | [ r, m ] ], ID(n)\n")
    Group create(@Param("entityInfo") EntityInfo entityInfo);
}